import { RequestPolicy, RequestPolicyFactory, RequestPolicyOptions, UserAgentOptions } from "@azure/core-http";
import { TelemetryPolicy } from "./policies/TelemetryPolicy";
/**
 * TelemetryPolicyFactory is a factory class helping generating {@link TelemetryPolicy} objects.
 *
 * @export
 * @class TelemetryPolicyFactory
 * @implements {RequestPolicyFactory}
 */
export declare class TelemetryPolicyFactory implements RequestPolicyFactory {
    /**
     * @internal
     * @ignore
     */
    readonly telemetryString: string;
    /**
     * Creates an instance of TelemetryPolicyFactory.
     * @param {UserAgentOptions} [telemetry]
     * @memberof TelemetryPolicyFactory
     */
    constructor(telemetry?: UserAgentOptions);
    /**
     * Creates a TelemetryPolicy object.
     *
     * @param {RequestPolicy} nextPolicy
     * @param {RequestPolicyOptions} options
     * @returns {TelemetryPolicy}
     * @memberof TelemetryPolicyFactory
     */
    create(nextPolicy: RequestPolicy, options: RequestPolicyOptions): TelemetryPolicy;
}
//# sourceMappingURL=TelemetryPolicyFactory.d.ts.map